dataMovies.services.imdbService API documentation

# Module `dataMovies.services.imdbService`

Expand source code

    from .imdbService import search_movie_reviews
    from .imdbService import search_movie_users_ratings

## Sub-modules

`dataMovies.services.imdbService.imdbApiCall`
`dataMovies.services.imdbService.imdbEndPoint`
`dataMovies.services.imdbService.imdbRequests`
`dataMovies.services.imdbService.imdbResponse`
`dataMovies.services.imdbService.imdbService`
`dataMovies.services.imdbService.utils`